@@ -7,7 +7,7 @@ use warnings;
 use Readonly;
 use Geoffrey::Action::Table;
 
-$Geoffrey::VERSION = '0.000203';
+$Geoffrey::VERSION = '0.000204';
 
 use parent 'Geoffrey::Role::Core';
 
@@ -79,7 +79,7 @@ sub insert {
 sub rewrite {
     my ($self, $hr_changeset) = @_;
     return unless $hr_changeset->{id};
-    return $self->delete($hr_changeset->{id}) ? $self->insert(q//, $hr_changeset) : 0;
+    return $self->delete($hr_changeset->{id}) ? $self->insert(q//, [$hr_changeset]) : 0;
 }
 
 sub load_changeset {
@@ -106,7 +106,7 @@ Geoffrey - Continuous Database Migration
 
 =head1 VERSION
 
-Version 0.000203
+Version 0.000204
 
 =head1 DESCRIPTION
 
